/*!
FullCalendar Adaptive Plugin v7.0.0-beta.4
Docs & License: https://fullcalendar.io/docs/print
(c) 2024 Adam Shaw
*/
FullCalendar.Adaptive = (function (exports, core, premiumCommonPlugin, internal) {
    'use strict';

    function _interopDefault (e) { return e && e.__esModule ? e : { 'default': e }; }

    var premiumCommonPlugin__default = /*#__PURE__*/_interopDefault(premiumCommonPlugin);

    let contexts = [];
    function contextInit(context) {
        if (!contexts.length) {
            attachGlobalHandlers();
        }
        contexts.push(context);
        context.calendarApi.on('_unmount', () => {
            internal.removeExact(contexts, context);
            if (!contexts.length) {
                removeGlobalHandlers();
            }
        });
    }
    function attachGlobalHandlers() {
        window.addEventListener('beforeprint', handleBeforePrint);
        window.addEventListener('afterprint', handleAfterPrint);
        /*
        // for testing
        let forPrint = false
        document.addEventListener('keypress', (ev) => {
          if (ev.key === 'p') {
            forPrint = !forPrint
            if (forPrint) {
              handleBeforePrint()
            } else {
              handleAfterPrint()
            }
          }
        })
        */
    }
    function removeGlobalHandlers() {
        window.removeEventListener('beforeprint', handleBeforePrint);
        window.removeEventListener('afterprint', handleAfterPrint);
    }
    function handleBeforePrint() {
        for (let context of contexts) {
            context.emitter.trigger('_beforeprint');
        }
    }
    function handleAfterPrint() {
        for (let context of contexts) {
            context.emitter.trigger('_afterprint');
        }
    }

    var css_248z = ".fc-break-inside-avoid{-moz-column-break-inside:avoid;break-inside:avoid}.fc-media-print .fc-h-event,.fc-media-print .fc-toolbar button,.fc-media-print .fc-v-event{background:#fff!important;color:#000!important}.fc-media-print .fc-event,.fc-media-print .fc-event-inner{color:#000!important}.fc-media-print .fc-print-root{border-collapse:collapse;border-spacing:0;display:table;table-layout:fixed;width:100%}.fc-media-print .fc-print-header{-moz-column-break-inside:avoid;background:#fff;break-inside:avoid;display:table-header-group;position:relative;z-index:9999}";
    internal.injectStyles(css_248z);

    var plugin = core.createPlugin({
        name: '@fullcalendar/adaptive',
        premiumReleaseDate: '2025-01-09',
        deps: [premiumCommonPlugin__default["default"]],
        contextInit,
    });

    core.globalPlugins.push(plugin);

    exports["default"] = plugin;

    Object.defineProperty(exports, '__esModule', { value: true });

    return exports;

})({}, FullCalendar, FullCalendar.PremiumCommon, FullCalendar.Internal);
